@@ -1,10 +1,12 @@
 package Pod::Weaver::Section::Leftovers;
 {
-  $Pod::Weaver::Section::Leftovers::VERSION = '3.101640';
+  $Pod::Weaver::Section::Leftovers::VERSION = '4.002';
 }
 use Moose;
-with 'Pod::Weaver::Role::Section';
-with 'Pod::Weaver::Role::Finalizer';
+with(
+  'Pod::Weaver::Role::Section',
+  'Pod::Weaver::Role::Finalizer',
+);
 # ABSTRACT: a place to put everything that nothing else used
 
 use Moose::Autobox;
@@ -68,7 +70,7 @@ Pod::Weaver::Section::Leftovers - a place to put everything that nothing else us
 
 =head1 VERSION
 
-version 3.101640
+version 4.002
 
 =head1 OVERVIEW
 
